@@ -22,7 +22,7 @@
 
 
 from web3 import HTTPProvider
-from web3.utils.request import make_post_request
+from web3._utils.request import make_post_request
 
 
 # Mostly copied from web3.py/providers/rpc.py. Supports batch requests.
